@@ -1,39 +1,12 @@
-=head1 NAME
-
-DBIx::SQLEngine::Criteria::Compound - Superclass for And and Or
-
-=head1 SYNOPSIS
-
-  my $crit = DBIx::SQLEngine::Criteria::CompoundSubclass->new( $crit, ... );
-
-
-=head1 DESCRIPTION
-
-DBIx::SQLEngine::Criteria::Compound objects are built around an array of other criteria.
-
-=cut
-
 package DBIx::SQLEngine::Criteria::Compound;
+
 @ISA = 'DBIx::SQLEngine::Criteria';
+
 use strict;
 use Carp;
 
 ########################################################################
 
-=head1 REFERENCE
-
-=head2 Constructor
-
-=over 4
-
-=item new ( @criteria ) : $compound
-
-Constructor.
-
-=back
-
-=cut
-
 sub new {
   my $package = shift;
   bless [ @_ ], $package;
@@ -41,22 +14,6 @@ sub new {
 
 ########################################################################
 
-=head2 Content Access
-
-=over 4
-
-=item subs () : @criteria
-
-Accessor
-
-=item push_subs ( @criteria ) 
-
-=item unshift_subs ( @criteria ) 
-
-=back
-
-=cut
-
 sub subs {
   my $crit = shift;
   @$crit
@@ -95,35 +52,80 @@ sub sql_where {
 
 ########################################################################
 
-=head1 CHANGES
+sub expr {
+  my $self = shift;
+  my %exprs;
+  foreach my $sub ( $self->subs ) {
+    if ( $sub->expr =~ /ARRAY/ ) {
+      map {
+        $exprs{ $_ } = 1;
+      } @{$sub->expr};
 
-2002-01-31 Remove redundant parentheses around single-item list.
+    } else {
+      $exprs{ $sub->expr } = 1;
+    }
+  }
+  my @exprs = keys %exprs;
+  return \@exprs;
+}
 
-2001-06-28 Moved to DBIx::O2:: namespace. Switched to Class::MakeMethods. Renamed from Group to Compound.
+1;
 
-2000-12-22 Added new_with_contents constructor
+########################################################################
 
-1999-01-31 Removed Data::Collection dependancy; now handled by Data::DRef.
+=head1 NAME
 
-1998-09-18 Updated to use MethodMaker::Compatibility instead of NamedFactory.
+DBIx::SQLEngine::Criteria::Compound - Superclass for And and Or
 
-1998-03-17 Split DBO::Criteria subclasses into new .pm files.
+=head1 SYNOPSIS
+
+  my $crit = DBIx::SQLEngine::Criteria::CompoundSubclass->new( $crit, ... );
 
 
-=head1 AUTHORS
+=head1 DESCRIPTION
 
-Developed by Evolution Online Systems:
-
-  M. Simon Cavalletto, simonm@evolution.com
+DBIx::SQLEngine::Criteria::Compound objects are built around an array of other criteria.
 
 
-=head1 LICENSE
+=head1 REFERENCE
 
-This module is free software. It may be used, redistributed and/or
-modified under the same terms as Perl.
+=head2 Constructor
 
-Copyright (c) 1996, 1997, 1999, 2000, 2001 Evolution Online Systems, Inc.
+=over 4
+
+=item new ( @criteria ) : $compound
+
+Constructor.
+
+=back
 
 =cut
 
-1;
+=head2 Content Access
+
+=over 4
+
+=item subs () : @criteria
+
+Accessor
+
+=item push_subs ( @criteria ) 
+
+=item unshift_subs ( @criteria ) 
+
+=back
+
+=cut
+
+
+=head1 SEE ALSO
+
+See L<DBIx::SQLEngine::Criteria> and L<DBIx::SQLEngine::Criteria::Comparison>
+for more information on using these objects.
+
+See L<DBIx::SQLEngine> for the overall interface and developer documentation.
+
+See L<DBIx::SQLEngine::Docs::ReadMe> for general information about
+this distribution, including installation and license information.
+
+=cut
